BorshArraySizedCodec<T> class

Array Sized Codec

A codec for fixed-length arrays with fixed size data types.

Inheritance
Mixed-in types

Constructors

BorshArraySizedCodec(BorshCodecFixedSized<T> subtype, int length)
Creates a codec for fixed-length arrays with fixed size data types.
const

Properties

byteLength → int
The number of bytes required to store any instance of T (i.e. max size).
no setteroverride
decoder → BorshArraySizedDecoder<T>
Returns the decoder of this, converting from T to S.
no setteroverride
encoder → BorshArraySizedEncoder<T>
Returns the encoder from S to T.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<Iterable<int>, List<T>>
Inverts this.
no setterinherited
length → int
The number of items in the array.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → BorshCodecFixedSized<T>
The subtype's codec.
finalinherited

Methods

cOption() → BorshOptionSizedCodec<List<T>>
Converts this codec to an c-option code of type T.
inherited
decode(Iterable<int> encoded) → List<T>
Decodes encoded data.
inherited
encode(List<T> input) → Iterable<int>
Encodes input.
inherited
fuse<R>(Codec<Iterable<int>, R> other) → Codec<List<T>, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option() → BorshOptionSizedCodec<List<T>>
Converts this codec to an option code of type T.
inherited
pack(BufferWriter buffer, List<T> input) → void
Writes input to buffer.
inherited
size(List<T> input) → int
Returns the serialized byte length of input.
inherited
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → List<T>
Reads T from buffer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited