BorshArraySizedDecoder<T> class

Array Sized Decoder

A decoder for fixed-length arrays with fixed size data types.

Inheritance

Constructors

BorshArraySizedDecoder(BorshCodecFixedSized<T> subtype, int length)
Creates a decoder for fixed-length arrays with fixed size data types.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
The number of items in the array.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → BorshCodecFixedSized<T>
The subtype's codec.
finalinherited

Methods

bind(Stream<Iterable<int>> stream) → Stream<List<T>>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Iterable<int> input) → List<T>
Decodes T from input.
inherited
fuse<TT>(Converter<List<T>, TT> other) → Converter<Iterable<int>, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<List<T>> sink) → Sink<Iterable<int>>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → List<T>
Reads T from buffer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited