BorshDateTimeCodec class

Date Time Codec

A codec for date time data types.

Inheritance
Mixed-in types

Constructors

BorshDateTimeCodec()
Creates a codec for date time data types.
const

Properties

byteLength → int
The number of bytes required to store any instance of T (i.e. max size).
no setteroverride
decoder → BorshDecoder<DateTime>
Returns the decoder of this, converting from T to S.
no setteroverride
encoder → BorshEncoder<DateTime>
Returns the encoder from S to T.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<Iterable<int>, DateTime>
Inverts this.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cOption() → BorshOptionSizedCodec<DateTime>
Converts this codec to an c-option code of type T.
inherited
decode(Iterable<int> encoded) → DateTime
Decodes encoded data.
inherited
encode(DateTime input) → Iterable<int>
Encodes input.
inherited
fuse<R>(Codec<Iterable<int>, R> other) → Codec<DateTime, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option() → BorshOptionSizedCodec<DateTime>
Converts this codec to an option code of type T.
inherited
pack(BufferWriter buffer, DateTime input) → void
Writes input to buffer.
inherited
size(DateTime input) → int
Returns the serialized byte length of input.
override
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → DateTime
Reads T from buffer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited