BorshEncoder<T> class abstract

Encoder

An interface for Borsh encoders.

Inheritance

Constructors

BorshEncoder()
Creates a encoder for T data types.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<T> stream) → Stream<Iterable<int>>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(T input) → Iterable<int>
Encodes input to byte data.
override
fuse<TT>(Converter<Iterable<int>, TT> other) → Converter<T, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(BufferWriter buffer, T input) → void
Writes input to buffer.
startChunkedConversion(Sink<Iterable<int>> sink) → Sink<T>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited