BorshInt16Codec class

Int16 Codec

A codec for signed 16-bit integers.

Inheritance

Constructors

BorshInt16Codec()
Creates a codec for signed 16-bit integers.
const

Properties

byteLength → int
The number of bytes required to store any instance of T (i.e. max size).
finalinherited
decoder → BorshDecoder<int>
Returns the decoder of this, converting from T to S.
no setterinherited
encoder → BorshEncoder<int>
Returns the encoder from S to T.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<Iterable<int>, int>
Inverts this.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cOption() → BorshOptionSizedCodec<int>
Converts this codec to an c-option code of type T.
inherited
decode(Iterable<int> encoded) → int
Decodes encoded data.
inherited
encode(int input) → Iterable<int>
Encodes input.
inherited
fuse<R>(Codec<Iterable<int>, R> other) → Codec<int, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option() → BorshOptionSizedCodec<int>
Converts this codec to an option code of type T.
inherited
pack(BufferWriter buffer, int input) → void
Writes input to buffer.
inherited
size(int input) → int
Returns the serialized byte length of input.
inherited
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → int
Reads T from buffer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited