BorshIntDecoder class

Int Decoder

A decoder for signed integers.

Inheritance

Constructors

BorshIntDecoder(int byteLength)
Creates a decoder for signed integers.
const

Properties

byteLength → int
The encoded byte length.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Iterable<int>> stream) → Stream<int>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Iterable<int> input) → int
Decodes T from input.
inherited
fuse<TT>(Converter<int, TT> other) → Converter<Iterable<int>, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<int> sink) → Sink<Iterable<int>>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → int
Reads T from buffer.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited