BorshIntEncoder class

Int Encoder

An encoder for signed integers.

Inheritance

Constructors

BorshIntEncoder(int byteLength)
Creates an encoder for signed integers.
const

Properties

byteLength → int
The fixed number of bytes required to store this data type.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<int> stream) → Stream<Iterable<int>>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(int input) → Iterable<int>
Encodes input to byte data.
inherited
fuse<TT>(Converter<Iterable<int>, TT> other) → Converter<int, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(BufferWriter buffer, int input) → void
Writes input to buffer.
override
startChunkedConversion(Sink<Iterable<int>> sink) → Sink<int>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited