BorshTupleCodec class

Tuple Codec

A codec for fixed-length arrays with multiple data types.

Inheritance

Constructors

BorshTupleCodec(List<BorshCodec> fields)
Creates a codec for fixed-length arrays with multiple data types.
const

Properties

decoder → BorshTupleDecoder
Returns the decoder of this, converting from T to S.
no setter
encoder → BorshTupleEncoder
Returns the encoder from S to T.
no setter
fields → List<BorshCodec>
The field type codecs.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<Iterable<int>, Tuple>
Inverts this.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Iterable<int> encoded) → Tuple
Decodes encoded data.
inherited
encode(Tuple input) → Iterable<int>
Encodes input.
inherited
fuse<R>(Codec<Iterable<int>, R> other) → Codec<Tuple, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(BufferWriter buffer, Tuple input) → void
Writes input to buffer.
inherited
size(List input) → int
Returns the serialized byte length of input.
inherited
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → Tuple
Reads T from buffer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited