BorshTupleEncoder class

Tuple Encoder

An encoder for fixed-length arrays with multiple data types.

Inheritance

Constructors

BorshTupleEncoder(List<BorshCodec> fields)
Creates an encoder for fixed-length arrays with multiple data types.
const

Properties

fields → List<BorshCodec>
The field type codecs.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Tuple> stream) → Stream<Iterable<int>>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Tuple input) → Iterable<int>
Encodes input to byte data.
inherited
fuse<TT>(Converter<Iterable<int>, TT> other) → Converter<Tuple, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(BufferWriter buffer, Tuple input) → void
Writes input to buffer.
inherited
startChunkedConversion(Sink<Iterable<int>> sink) → Sink<Tuple>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited