RustEnum<T> class

Rust Enum

A Rust style enum (tuple or struct constructor).

Implementers

Constructors

RustEnum(int index, [T? values])
Creates a Rust style enum (tuple or struct constructor).
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
The enum variant's index position.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → T?
The enum variant's constructor parameters.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited